@@ -1,3 +1,5 @@
+from keap import Keap
+
 try:
     from xmlrpclib import ServerProxy, Error
 except ImportError:
@@ -9,17 +11,16 @@ class BaseService:
     _service = None
     client = None
 
-    def __init__(self, keap):
+    def __init__(self, keap: Keap):
         self.keap = keap
         self.get_xmlrpc_client()
 
-    @property
-    def token(self):
-        return self.keap.token
-
     def get_xmlrpc_client(self):
-        uri = f"{self.xmlrpc_url}?access_token={self.token.access_token}"
-        self.client = ServerProxy(uri, use_datetime=self.use_datetime, allow_none=True)
+        if not self.keap.token.access_token:
+            raise Exception(f"No token set for client {self.keap.app_name}")
+        uri = f"{self.xmlrpc_url}?access_token={self.keap.token.access_token}"
+        self.client = ServerProxy(uri, use_datetime=self.keap.api_settings.USE_DATETIME,
+                                  allow_none=self.keap.api_settings.ALLOW_NONE)
         self.client.error = Error
         return self.client
 
@@ -36,7 +37,7 @@ class BaseService:
     def call(self, method, *args):
         call = getattr(self.client, f"{self.service}.{method}")
         try:
-            return call(self.token.access_token, *args)
+            return call(self.keap.token.access_token, *args)
         except self.client.error as v:
             return "ERROR", v
 
